@@ -2,11 +2,11 @@
 
 const Router = require('express').Router
 const passport = require('passport')
-var GoogleStrategy = require('passport-google-oauth20').Strategy
+const GoogleStrategy = require('passport-google-oauth20').Strategy
 const config = require('../../../config')
 const { passportGeneralCallback } = require('../utils')
 
-let googleAuth = module.exports = Router()
+const googleAuth = module.exports = Router()
 
 passport.use(new GoogleStrategy({
   clientID: config.google.clientID,
